@@ -5,7 +5,7 @@ Among the list maybe include nested list or doesn't
 '''
 
 
-def print_list(one_list):
+def print_list(one_list,parameter):
     '''
     This function will take a position parameter,named as "one_list".
     This could be any list of python
@@ -14,6 +14,8 @@ def print_list(one_list):
     '''
     for each in one_list:
         if isinstance(each,list):
-            print_list(each)
+            print_list(each,parameter+1)
         else:
+            for num in range(parameter):
+                print('\t',end='')
             print(each)
